結果
| 問題 | No.2444 一次変換と体積 |
| コンテスト | |
| ユーザー |
rlangevin
|
| 提出日時 | 2023-08-27 15:48:07 |
| 言語 | PyPy3 (8.0.0 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 24 ms / 2,000 ms |
| + 503µs | |
| コード長 | 401 bytes |
| 記録 | |
| コンパイル時間 | 67 ms |
| コンパイル使用メモリ | 80,992 KB |
| 実行使用メモリ | 54,528 KB |
| 最終ジャッジ日時 | 2026-10-08 16:40:53 |
| 合計ジャッジ時間 | 2,308 ms |
|
ジャッジサーバーID (参考情報) |
judge3_0 / judge2_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| other | AC * 20 |
ソースコード
N, B = map(int, input().split())
A = []
for i in range(3):
A.append(list(map(int, input().split())))
def det(M):
v = 0
v += M[0][0] * M[1][1] * M[2][2]
v += M[0][1] * M[1][2] * M[2][0]
v += M[0][2] * M[1][0] * M[2][1]
v -= M[0][2] * M[1][1] * M[2][0]
v -= M[0][1] * M[1][0] * M[2][2]
v -= M[0][0] * M[1][2] * M[2][1]
return v
print(pow(abs(det(A)), N, B))
rlangevin